pub enum AnimatedData {
Show 16 variants
Boolean(TimeDataMap<Boolean>),
Integer(TimeDataMap<Integer>),
Real(TimeDataMap<Real>),
String(TimeDataMap<String>),
Color(TimeDataMap<Color>),
Vector2(TimeDataMap<Vector2>),
Matrix3(TimeDataMap<Matrix3>),
BooleanVec(TimeDataMap<BooleanVec>),
IntegerVec(TimeDataMap<IntegerVec>),
RealVec(TimeDataMap<RealVec>),
ColorVec(TimeDataMap<ColorVec>),
StringVec(TimeDataMap<StringVec>),
Vector2Vec(TimeDataMap<Vector2Vec>),
Matrix3Vec(TimeDataMap<Matrix3Vec>),
RealCurve(TimeDataMap<RealCurve>),
ColorCurve(TimeDataMap<ColorCurve>),
}Expand description
Time-indexed data with interpolation support.
AnimatedData enum stores a collection of time-value pairs for a
specific data type and provides interpolation between keyframes. Each
variant contains a TimeDataMap for the corresponding data type.
Variants
Boolean(TimeDataMap<Boolean>)
Animated boolean values.
Integer(TimeDataMap<Integer>)
Animated integer values.
Real(TimeDataMap<Real>)
Animated real values.
String(TimeDataMap<String>)
Animated string values.
Color(TimeDataMap<Color>)
Animated color values.
Vector2(TimeDataMap<Vector2>)
Animated 2D vectors.
Matrix3(TimeDataMap<Matrix3>)
Animated transformation matrices.
BooleanVec(TimeDataMap<BooleanVec>)
Animated boolean vectors.
IntegerVec(TimeDataMap<IntegerVec>)
Animated integer vectors.
RealVec(TimeDataMap<RealVec>)
Animated real vectors.
ColorVec(TimeDataMap<ColorVec>)
Animated color vectors.
StringVec(TimeDataMap<StringVec>)
Animated string vectors.
Vector2Vec(TimeDataMap<Vector2Vec>)
Animated 2D vector arrays.
Matrix3Vec(TimeDataMap<Matrix3Vec>)
Animated matrix arrays.
RealCurve(TimeDataMap<RealCurve>)
Animated real curve.
ColorCurve(TimeDataMap<ColorCurve>)
Animated color curve.
Implementations
Sourceimpl AnimatedData
impl AnimatedData
Sourceimpl AnimatedData
impl AnimatedData
pub fn insert_boolean(&mut self, time: Time, value: Boolean) -> Result<()>
pub fn insert_integer(&mut self, time: Time, value: Integer) -> Result<()>
pub fn insert_real(&mut self, time: Time, value: Real) -> Result<()>
pub fn insert_string(&mut self, time: Time, value: String) -> Result<()>
pub fn insert_color(&mut self, time: Time, value: Color) -> Result<()>
Sourceimpl AnimatedData
impl AnimatedData
Sourceimpl AnimatedData
impl AnimatedData
Sourceimpl AnimatedData
impl AnimatedData
Sourcepub fn try_insert(&mut self, time: Time, value: Data) -> Result<()>
pub fn try_insert(&mut self, time: Time, value: Data) -> Result<()>
Generic insert method that takes Data and matches the type to the
AnimatedData variant.
Sourcepub fn remove_at(&mut self, time: &Time) -> Option<Data>
pub fn remove_at(&mut self, time: &Time) -> Option<Data>
Remove a sample at the given time.
Returns the removed value as Data if it existed. Returns None
if the key was not found or if it was the last sample (the non-empty
invariant prevents removing it). Use
Value::remove_or_make_uniform
to degrade to uniform instead.
pub fn sample_at(&self, time: Time) -> Option<Data>
pub fn interpolate(&self, time: Time) -> Data
Sourceimpl AnimatedData
impl AnimatedData
Sourcepub fn hash_with_shutter<H: Hasher>(&self, state: &mut H, shutter: &Shutter)
pub fn hash_with_shutter<H: Hasher>(&self, state: &mut H, shutter: &Shutter)
Hash the animated data with shutter context for better cache coherency.
Samples the animation at standardized points within the shutter range and hashes the interpolated values. If all samples are identical, only one value is hashed for efficiency.