Type Alias Vec2Impl
Source pub type Vec2Impl = Vec2;
#[repr(C)]
pub struct Vec2Impl {
pub x: f32,
pub y: f32,
}
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.