pub struct KeyDataMap<K, V> {
pub values: BTreeMap1<K, V>,
}Expand description
A generic key-value data map with interpolation support.
Stores key-value pairs in a BTreeMap1 for efficient ordered
queries and supports various interpolation methods. The map is
guaranteed to be non-empty at the type level.
When the interpolation feature is enabled, each value can have an
associated interpolation specification for animation curves.
Use the type alias TimeDataMap<V> for time-keyed maps (the common case),
or use KeyDataMap<Position, V> for curve-domain maps.
Fields
values: BTreeMap1<K, V>The key-value pairs with optional interpolation keys.
Guaranteed non-empty by BTreeMap1.
Implementations
Sourceimpl<K: Ord, V> KeyDataMap<K, V>
impl<K: Ord, V> KeyDataMap<K, V>
Sourceimpl<K: Ord, V> KeyDataMap<K, V>
impl<K: Ord, V> KeyDataMap<K, V>
Sourcepub fn from_single(key: K, value: V) -> Self
pub fn from_single(key: K, value: V) -> Self
Create a map with a single key-value pair.
Sourceimpl<K: Ord, V> KeyDataMap<K, V>
impl<K: Ord, V> KeyDataMap<K, V>
Sourceimpl<K, V> KeyDataMap<K, V>
impl<K, V> KeyDataMap<K, V>
pub fn interpolate(&self, key: K) -> V
Sourceimpl<K: Ord + Copy + Into<f32>, V> KeyDataMap<K, V>
impl<K: Ord + Copy + Into<f32>, V> KeyDataMap<K, V>
pub fn closest_sample(&self, key: K) -> &V
Sourcepub fn sample_at_or_before(&self, key: K) -> Option<&V>
pub fn sample_at_or_before(&self, key: K) -> Option<&V>
Get the value at or before the given key.
Sourcepub fn sample_at_or_after(&self, key: K) -> Option<&V>
pub fn sample_at_or_after(&self, key: K) -> Option<&V>
Get the value at or after the given key.